/*
 LiquidCrystal Library - display() and noDisplay()

 Demonstrates the use a 16x2 LCD display.  The LiquidCrystal
 library works with all LCD displays that are compatible with the
 Hitachi HD44780 driver. There are many of them out there, and you
 can usually tell them by the 16-pin interface.

 This sketch prints "Hello World!" to the LCD and uses the
 display() and noDisplay() functions to turn on and off
 the display.

 The circuit:
 * LCD RS pin to digital pin 12
 * LCD Enable pin to digital pin 11
 * LCD D4 pin to digital pin 5
 * LCD D5 pin to digital pin 4
 * LCD D6 pin to digital pin 3
 * LCD D7 pin to digital pin 2
 * LCD R/W pin to ground
 * 10K resistor:
 * ends to +5V and ground
 * wiper to LCD VO pin (pin 3)

 Library originally added 18 Apr 2008
 by David A. Mellis
 library modified 5 Jul 2009
 by Limor Fried (http://www.ladyada.net)
 example added 9 Jul 2009
 by Tom Igoe
 modified 22 Nov 2010
 by Tom Igoe

 This example code is in the public domain.

 http://www.arduino.cc/en/Tutorial/LiquidCrystalDisplay

 */
#include <Arduino.h>

// include the library code:
#include <LiquidCrystal.h>

// initialize the library with the numbers of the interface pins
LiquidCrystal lcd(12, 11, 0, 1, 2, 3, 4, 5, 6, 7);

//void setup() {
//	// set up the LCD's number of columns and rows:
//	lcd.begin(16, 2);
//	// Print a message to the LCD.
//	lcd.print("00000");
//}
//
//void loop() {
//	// Turn off the display:
//	lcd.noDisplay();
//	delay(100);
//	// Turn on the display:
//	lcd.display();
//	delay(100);
//}
//Pin connected to SH_CP of 74HC595
int clockPin = A0;
//Pin connected to ST_CP of 74HC595
int latchPin = A1;
////Pin connected to DS of 74HC595
int dataPin = A2;

void setup() {
	Serial.begin(9600);

	pinMode(9, OUTPUT);
	pinMode(10, OUTPUT);
	pinMode(13, OUTPUT);

	//set pins to output so you can control the shift register
	pinMode(latchPin, OUTPUT);
	pinMode(clockPin, OUTPUT);
	pinMode(dataPin, OUTPUT);

	// set up the LCD's number of columns and rows:
	lcd.begin(16, 2);
	// Print a message to the LCD.
	lcd.print("hello, world!");
	Serial.println("Hello world running inside Javr");
}

int lastSeconds = 0;
bool state = false;
int numberToDisplay = 0;

void loop() {
	int seconds = millis() / 1000;
	if (seconds != lastSeconds) {
		state = !state;
		digitalWrite(9, state);
		digitalWrite(10, state);
		digitalWrite(13, state);
	}

	// set the cursor to column 0, line 1
	// (note: line 1 is the second row, since counting begins with 0):
	lcd.setCursor(0, 1);
	// print the number of seconds since reset:
	lcd.print(seconds);
	lastSeconds = seconds;

	// take the latchPin low so
	// the LEDs don't change while you're sending in bits:
	digitalWrite(latchPin, LOW);
	// shift out the bits:
	shiftOut(dataPin, clockPin, MSBFIRST, numberToDisplay);

	//take the latch pin high so the LEDs will light up:
	digitalWrite(latchPin, HIGH);
	numberToDisplay++;

}
